==> openmw_0.48.0.orig.tar.gz: openmw-openmw-0.48.0/components/esm4/effect.hpp <==
/*
  Copyright (C) 2020 cc9cii

  This software is provided 'as-is', without any express or implied
  warranty.  In no event will the authors be held liable for any damages
  arising from the use of this software.

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.

  cc9cii cc9c@iinet.net.au

  Much of the information on the data structures are based on the information
  from Tes4Mod:Mod_File_Format and Tes5Mod:File_Formats but also refined by
  trial & error.  See http://en.uesp.net/wiki for details.

*/
#ifndef ESM4_EFFECT_H
#define ESM4_EFFECT_H

#include <cstdint>

#include "formid.hpp"

namespace ESM4
{
#pragma pack(push, 1)
    union EFI_Label
    {
        std::uint32_t value;
        char effect[4];
    };

    struct ScriptEffect
    {
        FormId       formId;       // Script effect (Magic effect must be SEFF)
        std::int32_t school;       // Magic school. See Magic schools for more information.
        EFI_Label    visualEffect; // Visual effect name or 0x00000000 if None
        std::uint8_t flags;        // 0x01 = Hostile
        std::uint8_t unknown1;
        std::uint8_t unknown2;
        std::uint8_t unknown3;
    };
#pragma pack(pop)
}

#endif // ESM4_EFFECT_H

==> openmw_0.49.0.orig.tar.gz: openmw-openmw-0.49.0/components/esm4/effect.hpp <==
/*
  Copyright (C) 2020 cc9cii

  This software is provided 'as-is', without any express or implied
  warranty.  In no event will the authors be held liable for any damages
  arising from the use of this software.

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.

  cc9cii cc9c@iinet.net.au

  Much of the information on the data structures are based on the information
  from Tes4Mod:Mod_File_Format and Tes5Mod:File_Formats but also refined by
  trial & error.  See http://en.uesp.net/wiki for details.

*/
#ifndef ESM4_EFFECT_H
#define ESM4_EFFECT_H

#include <cstdint>

#include <components/esm/formid.hpp>

namespace ESM4
{
#pragma pack(push, 1)
    union EFI_Label
    {
        std::uint32_t value;
        char effect[4];
    };

    struct ScriptEffect
    {
        ESM::FormId32 formId; // Script effect (Magic effect must be SEFF)
        std::int32_t school; // Magic school. See Magic schools for more information.
        EFI_Label visualEffect; // Visual effect name or 0x00000000 if None
        std::uint8_t flags; // 0x01 = Hostile
        std::uint8_t unknown1;
        std::uint8_t unknown2;
        std::uint8_t unknown3;
    };
#pragma pack(pop)
}

#endif // ESM4_EFFECT_H
